@@ -10,7 +10,7 @@ mod vtg;
 
 pub use bwc::{parse_bwc, BwcData};
 pub use gga::{parse_gga, GgaData};
-pub use gll::{parse_gll, GllData};
+pub use gll::{parse_gll, GllData, PosSystemIndicator};
 pub use gsa::{parse_gsa, GsaData};
 pub use gsv::{parse_gsv, GsvData};
 pub use rmc::{parse_rmc, RmcData, RmcStatusOfFix};
