@@ -76,6 +76,18 @@ pub(crate) fn parse_date(i: &[u8]) -> IResult<&[u8], NaiveDate> {
         )),
         |data| -> Result<NaiveDate, &'static str> {
             let (day, month, year) = (u32::from(data.0), u32::from(data.1), i32::from(data.2));
+
+            // We only receive a 2digit year code in this message, this has the potential
+            // to be ambiguous regarding the year. We assume that anything above 83 is 1900's, and
+            // anything above 0 is 2000's.
+            //
+            // The reason for 83 is that NMEA0183 was released in 1983.
+            // Parsing dates from ZDA messages is preferred, since it includes a 4 digit year.
+            let year = match year {
+                83..=99 => year + 1900,
+                _ => year + 2000,
+            };
+
             if !(1..=12).contains(&month) {
                 return Err("Invalid month < 1 or > 12");
             }
@@ -105,13 +117,13 @@ pub(crate) fn number<T: str::FromStr>(i: &[u8]) -> IResult<&[u8], T> {
 #[cfg(test)]
 mod tests {
     use super::*;
-    use approx::relative_eq;
+    use approx::assert_relative_eq;
 
     #[test]
     fn test_do_parse_lat_lon() {
         let (_, lat_lon) = do_parse_lat_lon(b"4807.038,N,01131.324,E").unwrap();
-        relative_eq!(lat_lon.0, 48. + 7.038 / 60.);
-        relative_eq!(lat_lon.1, 11. + 31.324 / 60.);
+        assert_relative_eq!(lat_lon.0, 48. + 7.038 / 60.);
+        assert_relative_eq!(lat_lon.1, 11. + 31.324 / 60.);
     }
 
     #[test]
@@ -128,4 +140,19 @@ mod tests {
         assert_eq!(time.second(), 19);
         assert_eq!(time.nanosecond(), 5_00_000_000);
     }
+
+    #[test]
+    fn test_parse_date() {
+        let (_, date) = parse_date(b"180283").unwrap();
+        assert_eq!(date, NaiveDate::from_ymd(1983, 02, 18));
+
+        let (_, date) = parse_date(b"180299").unwrap();
+        assert_eq!(date, NaiveDate::from_ymd(1999, 02, 18));
+
+        let (_, date) = parse_date(b"311200").unwrap();
+        assert_eq!(date, NaiveDate::from_ymd(2000, 12, 31));
+
+        let (_, date) = parse_date(b"311282").unwrap();
+        assert_eq!(date, NaiveDate::from_ymd(2082, 12, 31));
+    }
 }
